pub struct Scalar(pub(super) MontyFieldElement<ScalarParams, { ScalarParams::LIMBS }>);Expand description
Element in the NIST P-521 scalar field modulo n.
Trait impls
Much of the important functionality is provided by traits from the [ff] crate:
- [
Field] represents elements of finite fields and provides:- [
Field::random] generate a random field element double,square, andinvertoperations- Bounds for
Add,Sub,Mul, andNeg(and*Assignequivalents) - Bounds for
ConditionallySelectablefrom thesubtlecrate
- [
PrimeFieldrepresents elements of prime fields and provides:from_repr/to_reprfor converting field elements from/to big integers.MULTIPLICATIVE_GENERATORandROOT_OF_UNITYconstants.
Please see the documentation for the relevant traits for more information.
Tuple Fields
0: MontyFieldElement<ScalarParams, { ScalarParams::LIMBS }>Implementations
Sourceimpl Scalar
impl Scalar
Sourcepub fn from_bytes(
repr: &MontyFieldBytes<ScalarParams, { ScalarParams::LIMBS }>,
) -> CtOption<Self>
pub fn from_bytes( repr: &MontyFieldBytes<ScalarParams, { ScalarParams::LIMBS }>, ) -> CtOption<Self>
Create a Scalar from a canonical byte representation using the field’s configured byte order.
Sourcepub fn from_slice(slice: &[u8]) -> Option<Self>
pub fn from_slice(slice: &[u8]) -> Option<Self>
Decode Scalar from a byte slice using the field’s configured byte order.
Sourcepub const fn from_hex_vartime(hex: &str) -> Self
pub const fn from_hex_vartime(hex: &str) -> Self
Sourcepub fn to_bytes(self) -> MontyFieldBytes<ScalarParams, { ScalarParams::LIMBS }>
pub fn to_bytes(self) -> MontyFieldBytes<ScalarParams, { ScalarParams::LIMBS }>
Returns the big-endian encoding of this Scalar.
Sourcepub const fn pow_vartime<const RHS_LIMBS: usize>(
&self,
exp: &Uint<RHS_LIMBS>,
) -> Self
pub const fn pow_vartime<const RHS_LIMBS: usize>( &self, exp: &Uint<RHS_LIMBS>, ) -> Self
Returns self^exp, where exp is a little-endian integer exponent.
This operation is variable time with respect to the exponent exp.
If the exponent is fixed, this operation is constant time.
Sourcepub const fn sqn_vartime(&self, n: usize) -> Self
pub const fn sqn_vartime(&self, n: usize) -> Self
Returns self^(2^n) mod p.
This operation is variable time with respect to the exponent n.
If the exponent is fixed, this operation is constant time.
Sourceimpl Scalar
impl Scalar
Sourcepub(crate) const fn from_uint_unchecked(w: Uint) -> Self
pub(crate) const fn from_uint_unchecked(w: Uint) -> Self
Sourcepub const fn to_canonical(self) -> Uint
pub const fn to_canonical(self) -> Uint
Sourcepub fn invert_vartime(&self) -> CtOption<Self>
pub fn invert_vartime(&self) -> CtOption<Self>
Compute
Scalar
inversion: 1 / self in variable-time.
Sourcepub const fn const_invert(&self) -> Self
pub const fn const_invert(&self) -> Self
Compute field inversion as a const fn. Panics if self is zero.
This is mainly intended for inverting constants at compile time.